=== modified file 'NEWS'
--- NEWS	2010-03-11 18:00:23 +0000
+++ NEWS	2010-03-12 19:59:50 +0000
@@ -135,6 +135,10 @@
 API Changes
 ***********
 
+* ``bzrlib.merge_directive._BaseMergeDirective`` has been renamed to 
+  ``bzrlib.merge_directive.BaseMergeDirective`` and is now public.
+  (Jelmer Vernooij)
+
 * ``BranchFormat.initialize`` now takes an optional ``name`` of the colocated 
   branch to create. (Jelmer Vernooij)
 

=== modified file 'bzrlib/bundle/commands.py'
--- bzrlib/bundle/commands.py	2009-03-23 14:59:43 +0000
+++ bzrlib/bundle/commands.py	2010-03-12 19:59:50 +0000
@@ -54,7 +54,7 @@
         from bzrlib import osutils
         term_encoding = osutils.get_terminal_encoding()
         bundle_info = read_mergeable_from_url(location)
-        if isinstance(bundle_info, merge_directive._BaseMergeDirective):
+        if isinstance(bundle_info, merge_directive.BaseMergeDirective):
             bundle_file = StringIO(bundle_info.get_raw_bundle())
             bundle_info = read_bundle(bundle_file)
         else:

=== modified file 'bzrlib/hooks.py'
--- bzrlib/hooks.py	2010-02-17 17:11:16 +0000
+++ bzrlib/hooks.py	2010-03-12 19:59:50 +0000
@@ -59,7 +59,7 @@
     ('bzrlib.version_info_formats.format_rio', 'RioVersionInfoBuilder.hooks'),
     'bzrlib.version_info_formats.format_rio', 'RioVersionInfoBuilderHooks')
 known_hooks.register_lazy(
-    ('bzrlib.merge_directive', '_BaseMergeDirective.hooks'),
+    ('bzrlib.merge_directive', 'BaseMergeDirective.hooks'),
     'bzrlib.merge_directive', 'MergeDirectiveHooks')
 
 

=== modified file 'bzrlib/merge_directive.py'
--- bzrlib/merge_directive.py	2010-02-17 17:11:16 +0000
+++ bzrlib/merge_directive.py	2010-03-12 19:59:50 +0000
@@ -64,7 +64,7 @@
             " provided to the next.", (1, 15, 0), False))
 
 
-class _BaseMergeDirective(object):
+class BaseMergeDirective(object):
 
     hooks = MergeDirectiveHooks()
 
@@ -92,6 +92,20 @@
         self.source_branch = source_branch
         self.message = message
 
+    def to_lines(self):
+        """Serialize as a list of lines
+
+        :return: a list of lines
+        """
+        raise NotImplementedError(self.to_lines)
+
+    def get_raw_bundle(self):
+        """Return the bundle for this merge directive.
+
+        :return: bundle text or None if there is no bundle
+        """
+        return None
+
     def _to_lines(self, base_revision=False):
         """Serialize as a list of lines
 
@@ -303,7 +317,7 @@
                                           basename, body)
 
 
-class MergeDirective(_BaseMergeDirective):
+class MergeDirective(BaseMergeDirective):
 
     """A request to perform a merge into a branch.
 
@@ -338,7 +352,7 @@
         :param source_branch: A public location to merge the revision from
         :param message: The message to use when committing this merge
         """
-        _BaseMergeDirective.__init__(self, revision_id, testament_sha1, time,
+        BaseMergeDirective.__init__(self, revision_id, testament_sha1, time,
             timezone, target_branch, patch, source_branch, message)
         if patch_type not in (None, 'diff', 'bundle'):
             raise ValueError(patch_type)
@@ -428,7 +442,7 @@
         return None, self.revision_id, 'inapplicable'
 
 
-class MergeDirective2(_BaseMergeDirective):
+class MergeDirective2(BaseMergeDirective):
 
     _format_string = 'Bazaar merge directive format 2 (Bazaar 0.90)'
 
@@ -437,7 +451,7 @@
                  bundle=None, base_revision_id=None):
         if source_branch is None and bundle is None:
             raise errors.NoMergeSource()
-        _BaseMergeDirective.__init__(self, revision_id, testament_sha1, time,
+        BaseMergeDirective.__init__(self, revision_id, testament_sha1, time,
             timezone, target_branch, patch, source_branch, message)
         self.bundle = bundle
         self.base_revision_id = base_revision_id

